@@ -81,3 +81,34 @@ class department(base):
         }
         response = self.request(api_name=api_name, method="get", params=params)
         return response
+
+    def simplelist(self, id: int = None):
+        """获取子部门ID列表
+
+        Args:
+            id (int, optional): 部门id。获取指定部门及其下的子部门（以及及子部门的子部门等等，递归）。 如果不填，默认获取全量组织架构. Defaults to None.
+
+        Returns:
+            [type]: [description]
+        """
+        api_name = "department/simplelist"
+        params = {
+            "id": id,
+        }
+        response = self.request(api_name=api_name, method="get", params=params)
+        return response
+
+    def get(self, id: int):
+        """获取单个部门详情
+        Args:
+            id (int, optional): 	部门id。
+
+        Returns:
+            [type]: [description]
+        """
+        api_name = "department/get"
+        params = {
+            "id": id,
+        }
+        response = self.request(api_name=api_name, method="get", params=params)
+        return response
